/*
 * Configured Wi-Fi list adapter to list view
 *  for Wi-Fi view & select
 */
package jp.gr.java_conf.j_sota.wifiviewandselect;

import java.util.List;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.drawable.Drawable;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.TextView;

public class ConfiguredWifiListAdapter extends BaseAdapter {

	private List<ConfiguredWifiListData> mUserData;
	private LayoutInflater mInflater;
	private Context mContext;
	private LedColorList mLedColorList;

	/**
	 * Constructor
	 * @param context			Context
	 * @param users				Configured Wi-Fi data list
	 * @param ledColorList		LED color setting list
	 */
	public ConfiguredWifiListAdapter(Context context, List<ConfiguredWifiListData> users, LedColorList ledColorList) {
		mContext = context;
		mUserData = users;
		mLedColorList = ledColorList;
		mInflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
	}

	/**
	 * Set data
	 * @param users				Configured Wi-Fi data list
	 * @param ledColorList		LED color setting list
	 */
	public void setData(List<ConfiguredWifiListData> users, LedColorList ledColorList) {
		mUserData = users;
		mLedColorList = ledColorList;
	}

	/**
	 * Return a count of configured Wi-Fi list
	 * @return int 		Count
	 */
	public int getCount() {
		return mUserData.size();
	}

	/**
	 * Return a configured Wi-Fi data from position
	 * @param position
	 * @return Object 	Configured Wi-Fi data
	 */
	public Object getItem(int position) {
		return mUserData.get(position);
	}

	/**
	 * Return a item ID
	 * @param position		Position
	 * @return long 		Item ID
	 */
	public long getItemId(int position) {
		return position;
	}

	/**
	 * Return a view
	 * @param position		Position
	 * @param convertView	View
	 * @param parent		Parent
	 * @return View		view
	 */
	public View getView(int position, View convertView, ViewGroup parent) {
		View view = convertView;
		if (view == null) {
			view = mInflater.inflate(R.layout.selector_row, null);
		}
		ConfiguredWifiListData user = mUserData.get(position);

		// Show SSID
		TextView title = (TextView) view.findViewById(R.id.textSsid);
		title.setText(user.ssid);

		TextView outOfRange = (TextView) view.findViewById(R.id.textOutOfRange);
		ImageView mImageView = (ImageView) view.findViewById(R.id.imageSignalLevel);
		ImageView mImageLed = (ImageView) view.findViewById(R.id.imageLed);

		if (user.signalLevel == 0) {
			// Show 'Out of range' if signal level is zero
			outOfRange.setVisibility(View.VISIBLE);
			mImageView.setVisibility(View.INVISIBLE);
		} else {
			// Show signal level
			outOfRange.setVisibility(View.INVISIBLE);
			mImageView.setVisibility(View.VISIBLE);
			SignalLevelImage signalImage = new SignalLevelImage(view.getContext());
			Drawable drawable = signalImage.getSignalImage(user.signalLevel);
			mImageView.setImageDrawable(drawable);
		}

		// Show LED
		if (mLedColorList != null) {
			mImageLed.setVisibility(View.VISIBLE);
			LedImage ledImage = new LedImage(mContext);
			Bitmap bitmap = ledImage.getLedImage(mLedColorList.getLedColorFromSsid(user.ssid, user.networkId, mContext));
			mImageLed.setImageBitmap(bitmap);
		} else {
			mImageLed.setVisibility(View.INVISIBLE);
		}
		return view;
	}
}
